@@ -1,5 +1,5 @@
 /* footnotes.c -- Some functions for manipulating footnotes.
-   $Id: footnotes.c,v 1.3 2004/03/14 00:57:29 karl Exp $
+   $Id: footnotes.c,v 1.4 2004/04/06 22:58:25 karl Exp $
 
    Copyright (C) 1993, 1997, 1998, 1999, 2002, 2004 Free Software
    Foundation, Inc.
@@ -18,7 +18,7 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-   Written by Brian Fox (bfox@ai.mit.edu). */
+   Originally written by Brian Fox (bfox@ai.mit.edu). */
 
 #include "info.h"
 
@@ -30,7 +30,7 @@ static char *footnote_nodename = "*Footnotes*";
 NODE * make_footnotes_node (NODE *node);
 
 #define FOOTNOTE_HEADER_FORMAT \
-   "*** Footnotes appearing in the node \"%s\" ***\n"
+   "*** Footnotes appearing in the node `%s' ***\n"
 
 /* Find the window currently showing footnotes. */
 static WINDOW *
