@@ -1,5 +1,5 @@
 /* indices.c -- deal with an Info file index.
-   $Id: indices.c,v 1.3 2004/03/14 00:57:29 karl Exp $
+   $Id: indices.c,v 1.4 2004/04/06 22:58:25 karl Exp $
 
    Copyright (C) 1993, 1997, 1998, 1999, 2002, 2003, 2004 Free Software
    Foundation, Inc.
@@ -18,7 +18,7 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-   Written by Brian Fox (bfox@ai.mit.edu). */
+   Originally written by Brian Fox (bfox@ai.mit.edu). */
 
 #include "info.h"
 #include "indices.h"
@@ -372,7 +372,7 @@ DECLARE_INFO_COMMAND (info_next_index_match,
   /* If that failed, print an error. */
   if ((i < 0) || (!index_index[i]))
     {
-      info_error ((char *) _("No %sindex entries containing \"%s\"."),
+      info_error ((char *) _("No %sindex entries containing `%s'."),
                   index_offset > 0 ? (char *) _("more ") : "", index_search);
       return;
     }
@@ -419,7 +419,7 @@ DECLARE_INFO_COMMAND (info_next_index_match,
       char *format;
 
       format = replace_in_documentation
-        ((char *) _("Found \"%s\" in %s. (`\\[next-index-match]' tries to find next.)"),
+        ((char *) _("Found `%s' in %s. (`\\[next-index-match]' tries to find next.)"),
          0);
 
       window_message_in_echo_area (format, match, (char *) name);
@@ -538,7 +538,7 @@ apropos_in_all_indices (char *search_string, int inform)
 	  }
 
         if (this_fb && inform)
-          message_in_echo_area ((char *) _("Scanning indices of \"%s\"..."),
+          message_in_echo_area ((char *) _("Scanning indices of `%s'..."),
               files_name, NULL);
 
         this_index = info_indices_of_file_buffer (this_fb);
@@ -593,7 +593,7 @@ apropos_in_all_indices (char *search_string, int inform)
 }
 
 #define APROPOS_NONE \
-   N_("No available info files have \"%s\" in their indices.")
+   N_("No available info files have `%s' in their indices.")
 
 void
 info_apropos (char *string)
@@ -651,7 +651,7 @@ DECLARE_INFO_COMMAND (info_index_apropos,
 
           initialize_message_buffer ();
           printf_to_message_buffer
-            ((char *) _("\n* Menu: Nodes whose indices contain \"%s\":\n"),
+            ((char *) _("\n* Menu: Nodes whose indices contain `%s':\n"),
              line, NULL, NULL);
           line_buffer = (char *)xmalloc (500);
 
