@@ -1,5 +1,5 @@
 /* info-utils.c -- miscellanous.
-   $Id: info-utils.c,v 1.5 2004/03/14 00:57:29 karl Exp $
+   $Id: info-utils.c,v 1.6 2004/03/27 13:26:39 karl Exp $
 
    Copyright (C) 1993, 1998, 2003, 2004 Free Software Foundation, Inc.
 
@@ -17,7 +17,7 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-   Written by Brian Fox (bfox@ai.mit.edu). */
+   Originally written by Brian Fox (bfox@ai.mit.edu). */
 
 #include "info.h"
 #include "info-utils.h"
@@ -104,7 +104,11 @@ info_parse_node (char *string, int newlines_okay)
 
   /* Parse ``(line ...)'' part of menus, if any.  */
   {
-    char *rest = (char *) (string + i + 1);
+    char *rest = string + i;
+
+    /* Advance only if it's not already at end of string.  */
+    if (*rest)
+      rest++;
 
     /* Skip any whitespace first, and then a newline in case the item
        was so long to contain the ``(line ...)'' string in the same
