@@ -1,5 +1,5 @@
 /* m-x.c -- Meta-x minibuffer reader.
-   $Id: m-x.c,v 1.3 2004/03/14 00:57:29 karl Exp $
+   $Id: m-x.c,v 1.4 2004/03/20 22:15:57 karl Exp $
 
    Copyright (C) 1993, 1997, 1998, 2001, 2002, 2004 Free Software
    Foundation, Inc.
@@ -18,7 +18,7 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-   Written by Brian Fox (bfox@ai.mit.edu). */
+   Originally written by Brian Fox (bfox@ai.mit.edu). */
 
 #include "info.h"
 #include "funs.h"
@@ -148,7 +148,10 @@ DECLARE_INFO_COMMAND (info_execute_command,
     if (!command)
       return;
 
-    (*InfoFunction(command)) (active_window, count, 0);
+    if (InfoFunction(command))
+      (*InfoFunction(command)) (active_window, count, 0);
+    else
+      info_error ((char *) _("Undefined command: %s"), line, NULL);
   }
 }
 
