@@ -1,5 +1,5 @@
 /* nodes.c -- how to get an Info file and node.
-   $Id: nodes.c,v 1.3 2004/03/14 00:57:30 karl Exp $
+   $Id: nodes.c,v 1.4 2004/04/04 16:08:04 karl Exp $
 
    Copyright (C) 1993, 1998, 1999, 2000, 2002, 2003, 2004 Free Software
    Foundation, Inc.
@@ -18,7 +18,7 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-   Written by Brian Fox (bfox@ai.mit.edu). */
+   Originally written by Brian Fox (bfox@ai.mit.edu). */
 
 #include "info.h"
 
@@ -344,9 +344,9 @@ info_load_file_internal (char *filename, int get_tags)
         }
 
       fullpath = info_find_fullpath (lowered_name);
-      free (lowered_name);
 
       retcode = stat (fullpath, &finfo);
+      free (lowered_name);
     }
 
   /* If the file wasn't found, give up, returning a NULL pointer. */
