@@ -1,5 +1,5 @@
 /* terminal.c -- how to handle the physical terminal for Info.
-   $Id: terminal.c,v 1.3 2004/03/14 00:57:30 karl Exp $
+   $Id: terminal.c,v 1.4 2004/03/27 15:35:55 karl Exp $
 
    Copyright (C) 1988, 1989, 1990, 1991, 1992, 1993, 1996, 1997, 1998,
    1999, 2001, 2002, 2004 Free Software Foundation, Inc.
@@ -18,7 +18,7 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-   Written by Brian Fox (bfox@ai.mit.edu). */
+   Originally written by Brian Fox (bfox@ai.mit.edu). */
 
 #include "info.h"
 #include "terminal.h"
@@ -103,9 +103,6 @@ static char *visible_bell;
 /* The string to write to turn on the meta key, if this term has one. */
 static char *term_mm;
 
-/* The string to write to turn off the meta key, if this term has one. */
-static char *term_mo;
-
 /* The string to turn on inverse mode, if this term has one. */
 static char *term_invbeg;
 
@@ -622,12 +619,10 @@ terminal_initialize_terminal (char *terminal_name)
   if (terminal_has_meta_p)
     {
       term_mm = tgetstr ("mm", &buffer);
-      term_mo = tgetstr ("mo", &buffer);
     }
   else
     {
       term_mm = NULL;
-      term_mo = NULL;
     }
 
   /* Attempt to find the arrow keys.  */
