@@ -1,10 +1,10 @@
 /* variables.h -- Description of user visible variables in Info.
-   $Id: variables.h,v 1.1.1.1 2003/12/06 01:33:09 karl Exp $
+   $Id: variables.h,v 1.3 2004/03/14 00:57:30 karl Exp $
 
    This file is part of GNU Info, a program for reading online documentation
    stored in Info format.
 
-   Copyright (C) 1993, 97 Free Software Foundation, Inc.
+   Copyright (C) 1993, 1997, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -42,14 +42,15 @@ typedef struct {
 /* Read the name of an Info variable in the echo area and return the
    address of a VARIABLE_ALIST member.  A return value of NULL indicates
    that no variable could be read. */
-extern VARIABLE_ALIST *read_variable_name ();
+extern VARIABLE_ALIST *read_variable_name (char *prompt, WINDOW *window);
 
 /* Make an array of REFERENCE which actually contains the names of the
    variables available in Info. */
-extern REFERENCE **make_variable_completions_array ();
+extern REFERENCE **make_variable_completions_array (void);
 
 /* Set the value of an info variable. */
-extern void set_variable ();
+extern void set_variable (WINDOW *window, int count, unsigned char key);
+extern void describe_variable (WINDOW *window, int count, unsigned char key);
 
 /* The list of user-visible variables. */
 extern int auto_footnotes_p;
