@@ -1,5 +1,5 @@
 /* index.c -- indexing for Texinfo.
-   $Id: index.c,v 1.20 2004/03/01 15:28:06 dirt Exp $
+   $Id: index.c,v 1.22 2004/03/25 00:24:07 karl Exp $
 
    Copyright (C) 1998, 1999, 2002, 2003, 2004 Free Software Foundation,
    Inc.
@@ -653,18 +653,18 @@ insert_index_output_line_no (int line_number, int output_line_number_len)
   int last_column;
   int str_size = output_line_number_len + strlen (_("(line )"))
     + sizeof (NULL);
-  char *out_line_no_str = (char *) xmalloc (str_size);
+  char *out_line_no_str = (char *) xmalloc (str_size + 1);
 
   /* Do not translate ``(line NNN)'' below for !no_headers case (Info output),
      because it's something like the ``* Menu'' strings.  For plaintext output
      it should be translated though.  */
-  snprintf (out_line_no_str, str_size,
+  sprintf (out_line_no_str,
       no_headers ? _("(line %*d)") : "(line %*d)",
       output_line_number_len, line_number);
 
   {
     int i = output_paragraph_offset; 
-    while (output_paragraph[i-1] != '\n' && i > 0)
+    while (0 < i && output_paragraph[i-1] != '\n')
       i--;
     last_column = output_paragraph_offset - i;
   }
@@ -713,13 +713,13 @@ cm_printindex (void)
   else if (!handling_delayed_writes)
     {
       int command_len = sizeof ("@ ") + strlen (command) + strlen (index_name);
-      char *index_command = xmalloc (command_len);
+      char *index_command = xmalloc (command_len + 1);
 
       close_paragraph ();
       if (docbook)
         xml_begin_index ();
 
-      snprintf (index_command, command_len, "@%s %s", command, index_name);
+      sprintf (index_command, "@%s %s", command, index_name);
       register_delayed_write (index_command);
       free (index_command);
     }
@@ -781,15 +781,14 @@ cm_printindex (void)
         char *max_output_line_number = (char *) xmalloc (25 * sizeof (char));
 
         if (no_headers)
-          snprintf (max_output_line_number, 25 * sizeof (char), "%d",
-              output_line_number);
+          sprintf (max_output_line_number, "%d", output_line_number);
         else
           {
             INDEX_ELT *tmp_entry = index;
             unsigned tmp = 0;
             for (tmp_entry = index; tmp_entry; tmp_entry = tmp_entry->next)
               tmp = tmp_entry->output_line > tmp ? tmp_entry->output_line : tmp;
-            snprintf (max_output_line_number, 25 * sizeof (char), "%d", tmp);
+            sprintf (max_output_line_number, "%d", tmp);
           }
 
         output_line_number_len = strlen (max_output_line_number);
