@@ -1,5 +1,5 @@
 /* insertion.c -- insertions for Texinfo.
-   $Id: insertion.c,v 1.35 2004/02/28 13:33:26 dirt Exp $
+   $Id: insertion.c,v 1.39 2004/04/09 13:09:54 dirt Exp $
 
    Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004 Free Software
    Foundation, Inc.
@@ -510,6 +510,7 @@ begin_insertion (enum insertion_type type)
         /* Save the copying text away for @insertcopying,
            typically used on the back of the @titlepage (for TeX) and
            the Top node (for info/html).  */
+      if (input_text[input_text_offset] != '\n')
         discard_until ("\n"); /* ignore remainder of @copying line */
 
         input_text_offset = get_until ("\n@end copying", &copying_text);
@@ -1048,6 +1049,9 @@ end_insertion (int type)
     {
       /* Insertions which have no effect on paragraph formatting. */
     case copying:
+      line_number--;
+      break;
+
     case documentdescription:
     case ifclear:
     case ifdocbook:
@@ -1117,18 +1121,18 @@ end_insertion (int type)
       close_insertion_paragraph ();
       current_indent -= default_indentation_increment;
       if (html)
-        add_word ("</ol>\n");
+        add_html_block_elt ("</ol>\n");
       break;
 
     case flushleft:
       if (html)
-        add_word ("</div>\n");
+        add_html_block_elt ("</div>\n");
       close_insertion_paragraph ();
       break;
 
     case cartouche:
       if (html)
-	add_word ("</td></tr></table>\n");
+	add_html_block_elt ("</td></tr></table>\n");
       close_insertion_paragraph ();
       break;
 
@@ -1220,6 +1224,10 @@ end_insertion (int type)
          start of a new paragraph, except for the XML output. */
       if (!xml || docbook)
         close_insertion_paragraph ();
+
+      /* </pre> closes paragraph without messing with </p>.  */
+      if (html && type != quotation)
+          paragraph_is_open = 0;
       break;
 
     case table:
@@ -1966,19 +1974,24 @@ cm_author (void)
   if (is_in_insertion_of_type (quotation))
     {
       if (html)
+        add_word_args ("&mdash; %s", rest);
+      else if (docbook)
         {
-          add_word ("&mdash;");
-          add_word ("&mdash;");
+          /* FIXME Ideally, we should use an attribution element,
+             but they are supposed to be at the start of quotation
+             blocks.  So to avoid looking ahead mess, let's just
+             use mdash like HTML for now.  */
+          xml_insert_entity ("mdash");
+          add_word (rest);
         }
       else if (xml)
         {
-          xml_insert_entity ("mdash");
-          xml_insert_entity ("mdash");
+          xml_insert_element (AUTHOR, START);
+          add_word (rest);
+          xml_insert_element (AUTHOR, END);
         }
       else
-        add_word ("--");
-
-        add_word (rest);
+        add_word_args ("-- %s", rest);
     }
   else if (is_in_insertion_of_type (titlepage))
     {
