@@ -1,5 +1,5 @@
 /* sectioning.c -- for @chapter, @section, ..., @contents ...
-   $Id: sectioning.c,v 1.12 2004/03/12 18:21:06 karl Exp $
+   $Id: sectioning.c,v 1.15 2004/04/06 22:48:30 karl Exp $
 
    Copyright (C) 1999, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
@@ -336,6 +336,23 @@ sectioning_underscore (char *cmd)
     level = 0;
   free (temp);
 
+  /* If the argument to @top is empty, we try using the one from @settitle.
+     Warn if both are unusable.  */
+  if (STREQ (command, "top"))
+    {
+      int save_input_text_offset = input_text_offset;
+
+      get_rest_of_line (0, &temp);
+
+      /* Due to get_rest_of_line ... */
+      line_number--;
+
+      if (strlen (temp) == 0 && (!title || strlen (title) == 0))
+        warning ("Must specify a title with least one of @settitle or @top");
+
+      input_text_offset = save_input_text_offset;
+    }
+
   if (xml)
     {
       /* If the section appears in the toc, it means it's a real section
@@ -350,6 +367,7 @@ sectioning_underscore (char *cmd)
 	  xml_last_section_output_position = output_paragraph_offset;
 
 	  get_rest_of_line (0, &temp);
+
           /* Use @settitle value if @top parameter is empty.  */
           if (STREQ (command, "top") && strlen(temp) == 0)
             temp = xstrdup (title ? title : "");
@@ -404,10 +422,7 @@ sectioning_underscore (char *cmd)
   else if (html)
     sectioning_html (level, secname);
   else
-    {
-      char character = scoring_characters[level];
-      insert_and_underscore (level, character, secname);
-    }
+    insert_and_underscore (level, secname);
 }
 
 
@@ -415,13 +430,14 @@ sectioning_underscore (char *cmd)
    in a new, separate paragraph.  Directly underneath it, insert a
    line of WITH_CHAR, the same length of the inserted text. */
 void
-insert_and_underscore (int level, int with_char, char *cmd)
+insert_and_underscore (int level, char *cmd)
 {
   int i, len;
   int index;
   int old_no_indent;
   unsigned char *starting_pos, *ending_pos;
   char *temp;
+  char with_char = scoring_characters[level];
 
   close_paragraph ();
   filling_enabled =  indented_fill = 0;
@@ -432,6 +448,11 @@ insert_and_underscore (int level, int with_char, char *cmd)
     append_to_expansion_output (input_text_offset + 1);
 
   get_rest_of_line (0, &temp);
+
+  /* Use @settitle value if @top parameter is empty.  */
+  if (STREQ (command, "top") && strlen(temp) == 0)
+    temp = xstrdup (title ? title : "");
+
   starting_pos = output_paragraph + output_paragraph_offset;
 
   /* Poor man's cache for section title.  */
@@ -443,7 +464,7 @@ insert_and_underscore (int level, int with_char, char *cmd)
   if (index < 0)
     {
       /* should never happen, but a poor guy, named Murphy ... */
-      warning (_("Internal error (search_sectioning) \"%s\"!"), cmd);
+      warning (_("Internal error (search_sectioning) `%s'!"), cmd);
       return;
     }
 
@@ -530,6 +551,10 @@ sectioning_html (int level, char *cmd)
 
   get_rest_of_line (0, &temp);
 
+  /* Use @settitle value if @top parameter is empty.  */
+  if (STREQ (command, "top") && strlen(temp) == 0)
+    temp = xstrdup (title ? title : "");
+
   index = search_sectioning (cmd);
   if (index < 0)
     {
